# Getting Started

Welcome to TuFT! This section will help you get up and running quickly.

```{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card} Installation
:link: installation
:link-type: doc
:shadow: none

Install TuFT from source, PyPI, or Docker.
:::

:::{grid-item-card} Quickstart
:link: quickstart
:link-type: doc
:shadow: none

Run your first training and sampling example with TuFT.
:::
```

```{toctree}
:maxdepth: 1
:hidden:

installation
quickstart
```
